<?php

namespace Drupal\group_subscription\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a block the user can use to manage their subscription for a group.
 *
 * @Block(
 *   id = "group_subscription",
 *   admin_label = @Translation("Group Subscription"),
 *   context = {
 *     "group" = @ContextDefinition("entity:group", required = FALSE)
 *   }
 * )
 */
class GroupSubscriptionBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    // See if we are viewing a group.
    if (($group = $this->getContextValue('group')) && $group->id()) {
      $user = \Drupal::currentUser();

      // See if the current user is a member of this group.
      if ($group->getMember($user)) {
        $form = \Drupal::formBuilder()->getForm('Drupal\group_subscription\Form\GroupSubscriptionBlockForm');
        return $form;
      }
    }
  }

  /**
   * @return int
   */
  public function getCacheMaxAge() {
    // We do not want to cache this block.
    return 0;
  }
}
